import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { UnidadOrganizativa } from './model';

@Injectable({
  providedIn: 'root'
})
export class DataService {

  private apiUrl = 'http://127.0.0.1:8080/organizational-units?page=1&itemsPerPage=1000';
  private clientsUrl = 'http://127.0.0.1:8080/clients?page=1&itemsPerPage=30';

  constructor(private http: HttpClient) {}

  getOrganizationalUnits(search: string = ''): Observable<UnidadOrganizativa[]> {
    let url = `${this.apiUrl}&type=organizational-unit`;
    if (search) {
      url += `&name=${encodeURIComponent(search)}`;
    }

    return this.http.get<any>(url).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'];
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching unidades organizativas', error);
        return throwError(error);
      })
    );
  }

  getChildren(id: string): Observable<any[]> {
    return this.http.get<any>(`${this.apiUrl}&parent.id=${id}`).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member']
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching children', error);
        return throwError(error);
      })
    );
  }

  getClients(id: string): Observable<any[]> {
    return this.http.get<any>(`${this.clientsUrl}&organizationalUnit.id=${id}`).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member']
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching clients', error);
        return throwError(error);
      })
    );
  }

  getHardwareProfiles():  Observable<any[]> {
    const url = 'http://127.0.0.1:8080/hardware-profiles';
    return this.http.get<any>(url).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member']
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching clients', error);
        return throwError(error);
      })
    );
  }

  deleteElement(uuid: string, type: string): Observable<void> {
    const url = type === 'client'
      ? `http://127.0.0.1:8080/clients/${uuid}`
      : `http://127.0.0.1:8080/organizational-units/${uuid}`;
    return this.http.delete<void>(url).pipe(
      catchError(error => {
        console.error('Error deleting element', error);
        return throwError(error);
      })
    );
  }

  changeParent(uuid: string): Observable<void> {
    const url = `http://127.0.0.1:8080/organizational-units/${uuid}/change-parent`;
    // @ts-ignore
    return this.http.post<void>(url).pipe(
      catchError(error => {
        console.error('Error deleting element', error);
        return throwError(error);
      })
    );
  }


}
